@@ -1,14 +1,13 @@
 
-test_that("wksxp writing is vectorized", {
+test_that("wk_translate.wkt works", {
   expect_identical(
-    wkt_translate_wksxp(c("POINT (20 20)", "POINT (30 30)")),
-    list(
-      structure(matrix(c(20, 20),  ncol = 2), class = "wk_point"),
-      structure(matrix(c(30, 30),  ncol = 2), class = "wk_point")
-    )
+    wk_translate(as_wkb("POINT (1 2)"), wkt()),
+    wkt("POINT (1 2)")
   )
 })
 
+
+
 test_that("wkt writing is vectorized", {
   expect_identical(
     wkt_translate_wkt(c("POINT (20 20)", "POINT (30 30)")),
